==> opengnsys-0.9.2-r1301.tar.gz: opengnsys/admin/WebConsole/idiomas/php/eng/colasacciones_eng.php <==
<?
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: colasacciones_eng.php 
//	Idioma: Ings 
//________________________________________________________________________________________________________

// Literales de los tipo de acciones
$LITEJECUCION_COMANDO="Commands";
$LITEJECUCION_PROCEDIMIENTO="Procedures";
$LITEJECUCION_TAREA="Tasks";
$LITEJECUCION_TRABAJO="Jobs";

$LITACCION_EXITOSA='Finished successfully'; // Literal  Finalizada con exito
$LITACCION_FALLIDA='Finished with errors'; // Literal  Finalizada con errores
$LITACCION_TERMINADA='Finished manualy'; //Literal   Finalizada manualmente con indicacion de exito 
$LITACCION_ABORTADA='Canceled manualy'; // Literal  Finalizada manualmente con indicacion de errores 
$LITACCION_SINERRORES='Active without errors'; // Literal  Activa y sin ningn error
$LITACCION_CONERRORES='Active with errors'; // Literal  Activa y con algn error

$LITACCION_DETENIDA='Stopped'; // Literal accin momentanemente parada
$LITACCION_INICIADA='Active'; // Literal accin activa
$LITACCION_FINALIZADA='Finished'; // Literal accin finalizada

$TbMsg=array();
	$TbMsg[0]='Actions queue';
	$TbMsg[1]='Searches filters';
	$TbMsg[2]='Actions';
	$TbMsg[3]='Results';
	$TbMsg[4]='Status';
	$TbMsg[5]='Percentage from';
	$TbMsg[6]='to';
	$TbMsg[7]='Start date';
	$TbMsg[8]='Finish date';
	$TbMsg[9]='Start our';
	$TbMsg[10]='Finish our';
	$TbMsg[11]='Environment';
	$TbMsg[12]='Remove';
	$TbMsg[13]='Reinitialize';
	$TbMsg[14]='Stop';
	$TbMsg[15]='Go';
	$TbMsg[16]='Cancel';
	$TbMsg[17]='Finish';

	$TbMsg[18]='Action';
	$TbMsg[19]='Finish date';
	$TbMsg[20]='Finish our';
	$TbMsg[21]='Start date';
	$TbMsg[22]='Start our';
	$TbMsg[23]='Name';

	$TbMsg[24]='Centers';
	$TbMsg[25]='Group of labs';
	$TbMsg[26]='Labs';
	$TbMsg[27]='Group of computers';
	$TbMsg[28]='Computers';

	$TbMsg[30]='Commands';
	$TbMsg[31]='Tasks';
	$TbMsg[32]='Jobs';

	$TbMsg[41]='"Accion filter"';
	$TbMsg[42]='"Environment filter"';
	$TbMsg[43]='"Remove filter"';
	$TbMsg[44]='"Modify Accin"';
	$TbMsg[45]='"Reinitialize"';
	$TbMsg[46]='"Remove"';
	$TbMsg[47]='"Parent Task"';
	$TbMsg[48]='"Parent Job"';
	$TbMsg[49]='"See commands"';
	$TbMsg[50]='"See task"';
	$TbMsg[51]='"Stop"';
	$TbMsg[52]='"Go"';
	$TbMsg[53]='"Cancel"';
	$TbMsg[54]='"Finish"';
	$TbMsg[55]='"Finish without errors"';
	$TbMsg[56]='"Finish with errors"';
	$TbMsg[57]='Information';
?>

==> opengnsys-1.1.0-r5652.tar.gz: opengnsys/admin/WebConsole/idiomas/php/eng/colasacciones_eng.php <==
<?php
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: colasacciones_eng.php 
//	Idioma: Ings 
//________________________________________________________________________________________________________

// Literales de los tipo de acciones
$LITEJECUCION_COMANDO="Commands";
$LITEJECUCION_PROCEDIMIENTO="Procedures";
$LITEJECUCION_TAREA="Tasks";
//$LITEJECUCION_TRABAJO="Jobs";

$LITACCION_EXITOSA='Finished successfully'; // Literal  Finalizada con exito
$LITACCION_FALLIDA='Finished with errors'; // Literal  Finalizada con errores
//$LITACCION_SINRESULTADO='Without final result'
$LITACCION_TERMINADA='Finished manualy'; //Literal   Finalizada manualmente con indicacion de exito 
$LITACCION_ABORTADA='Canceled manualy'; // Literal  Finalizada manualmente con indicacion de errores 
$LITACCION_SINERRORES='Active without errors'; // Literal  Activa y sin ningn error
$LITACCION_CONERRORES='Active with errors'; // Literal  Activa y con algn error

$LITACCION_DETENIDA='Stopped'; // Literal accin momentanemente parada
$LITACCION_INICIADA='Active'; // Literal accin activa
$LITACCION_FINALIZADA='Finished'; // Literal accin finalizada
$LITACCION_PROGRAMADA="Scheduled";

$TbMsg=array();
	$TbMsg[0]='Actions queue';
	$TbMsg[1]='Search filters';
	$TbMsg[2]='Actions';
	$TbMsg[3]='Results';
	$TbMsg[4]='Status';
	$TbMsg[5]='Percentage from';
	$TbMsg[6]='to';
	$TbMsg[7]='Start date';
	$TbMsg[8]='Finish date';
	$TbMsg[9]='Start our';
	$TbMsg[10]='Finish our';
	$TbMsg[11]='Scope';
	$TbMsg[12]='Remove';
	$TbMsg[13]='Reinitialize';
	$TbMsg[14]='Stop';
	$TbMsg[15]='Go';
	$TbMsg[16]='Cancel';
	$TbMsg[17]='Finish';

	$TbMsg[18]='Action';
	$TbMsg[19]='Finish date';
	$TbMsg[20]='Finish hour';
	$TbMsg[21]='Start date';
	$TbMsg[22]='Start hour';
	$TbMsg[23]='Name';

	$TbMsg[24]='Centers';
	$TbMsg[25]='Group of labs';
	$TbMsg[26]='Labs';
	$TbMsg[27]='Group of computers';
	$TbMsg[28]='Computers';

	$TbMsg[30]='Commands';
	$TbMsg[31]='Tasks';
	$TbMsg[32]='Jobs';

	$TbMsg[41]='"Accion filter"';
	$TbMsg[42]='"Environment filter"';
	$TbMsg[43]='"Remove filter"';
	$TbMsg[44]='"Modify Accin"';
	$TbMsg[45]='"Reinitialize"';
	$TbMsg[46]='"Remove"';
	$TbMsg[47]='Parent Task';
	$TbMsg[48]='Parent Job';
	$TbMsg[49]='See commands';
	$TbMsg[50]='See task';
	$TbMsg[51]='"Stop"';
	$TbMsg[52]='"Go"';
	$TbMsg[53]='"Cancel"';
	$TbMsg[54]='"Finish"';
	$TbMsg[55]='Finish without errors';
	$TbMsg[56]='Finish with errors';
	$TbMsg[57]='Information';
        $TbMsg[58]='Final result:';
        $TbMsg[59]='Scope';
        $TbMsg[60]='All';
        $TbMsg[61]='All';
?>
